==> huaweicloudsdkworkspace-3.1.87-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/show_desktop_detail_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDesktopDetailResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'desktop': 'DesktopDetailInfo'
    }

    attribute_map = {
        'desktop': 'desktop'
    }

    def __init__(self, desktop=None):
        """ShowDesktopDetailResponse

        The model defined in huaweicloud sdk

        :param desktop: 
        :type desktop: :class:`huaweicloudsdkworkspace.v2.DesktopDetailInfo`
        """
        
        super(ShowDesktopDetailResponse, self).__init__()

        self._desktop = None
        self.discriminator = None

        if desktop is not None:
            self.desktop = desktop

    @property
    def desktop(self):
        """Gets the desktop of this ShowDesktopDetailResponse.

        :return: The desktop of this ShowDesktopDetailResponse.
        :rtype: :class:`huaweicloudsdkworkspace.v2.DesktopDetailInfo`
        """
        return self._desktop

    @desktop.setter
    def desktop(self, desktop):
        """Sets the desktop of this ShowDesktopDetailResponse.

        :param desktop: The desktop of this ShowDesktopDetailResponse.
        :type desktop: :class:`huaweicloudsdkworkspace.v2.DesktopDetailInfo`
        """
        self._desktop = desktop

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDesktopDetailResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/show_desktop_detail_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowDesktopDetailResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'desktop': 'DesktopDetailInfo'
    }

    attribute_map = {
        'desktop': 'desktop'
    }

    def __init__(self, desktop=None):
        r"""ShowDesktopDetailResponse

        The model defined in huaweicloud sdk

        :param desktop: 
        :type desktop: :class:`huaweicloudsdkworkspace.v2.DesktopDetailInfo`
        """
        
        super(ShowDesktopDetailResponse, self).__init__()

        self._desktop = None
        self.discriminator = None

        if desktop is not None:
            self.desktop = desktop

    @property
    def desktop(self):
        r"""Gets the desktop of this ShowDesktopDetailResponse.

        :return: The desktop of this ShowDesktopDetailResponse.
        :rtype: :class:`huaweicloudsdkworkspace.v2.DesktopDetailInfo`
        """
        return self._desktop

    @desktop.setter
    def desktop(self, desktop):
        r"""Sets the desktop of this ShowDesktopDetailResponse.

        :param desktop: The desktop of this ShowDesktopDetailResponse.
        :type desktop: :class:`huaweicloudsdkworkspace.v2.DesktopDetailInfo`
        """
        self._desktop = desktop

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDesktopDetailResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
